@@ -7,6 +7,7 @@ from netaddr import IPNetwork, AddrFormatError
 from ground_soil.fabric import eval_kwargs
 from ground_soil.filesystem import temporary_directory, rsync
 from beanstalk import IDENTIFIER as beanstalk_identifier, BEANSTALK_LOCAL_BASE_PATH
+import beanstalk
 from beanstalk.tasks.utils import (set_verbose_level, load_role_settings as load_beanstalk_settings,
                                    load_web_servers, run_hooked_actions)
 from beanstalk.decorators import beanstalk_role
@@ -170,14 +171,17 @@ def deploy(settings_path=None, **settings_patches):
                 print ''
 
             # Call pre-deploy script
-            run_hooked_actions('PRE_DEPLOY_ACTIONS')
+            if run_hooked_actions('PRE_DEPLOY_ACTIONS'):
+                print ''
 
             # Work on remote
+            print '+' * 80
             with settings(hide('running')):
                 execute(deploy_remote_core)
 
             # Call post-deploy script
-            run_hooked_actions('POST_DEPLOY_ACTIONS')
+            if run_hooked_actions('POST_DEPLOY_ACTIONS'):
+                print ''
 
 
 @roles('web_servers')
@@ -195,6 +199,10 @@ def deploy_remote_core():
                 red('Hey! I cannot find Jack at ') + red(host_name, bold=True) + red('. ') +
                 'Please setup beanstalk-stack on this server first.'
             )
+        remote_bs_version = json.loads(run('bsjack info.version,USE_JSON=True --hide=status'))
+        if beanstalk.VERSION != (remote_bs_version['list']):
+            abort(red('Hey! Jack at the remote is not the same as me. He\'s %s. But I\'m %s.') %
+                  (remote_bs_version['string'], beanstalk.__version__))
 
     # Get/Set variables
     beanstalk_settings = env.beanstalk_settings
@@ -202,7 +210,7 @@ def deploy_remote_core():
     verbose_level = beanstalk_settings['VERBOSE']
 
     # Create this app to server
-    print section_title('Create app if it\'s not existed.')
+    print section_title('Find room for %s' % project_name)
     run('bsjack server.create_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
 
     # Call pre-install script
@@ -216,7 +224,7 @@ def deploy_remote_core():
     remote_base_path = app_info['path']['base']
     remote_source_path = app_info['path']['source']
 
-    print section_title('Send codebase to remote: %s' % white(remote_base_path))
+    print section_title('Send %s to remote: %s' % (project_name, white(remote_base_path)))
     # Send code
     rsync_argument = '-DLhrctz --delete --delete-excluded'
     rsync_argument += ' --exclude \'*.pyc\' --exclude \'*.pyo\' --exclude-from \'.gitignore\''
@@ -232,16 +240,18 @@ def deploy_remote_core():
     local(rsync('%s/.gitignore' % env.temp_directory, target_base_path))
 
     # Call post-install script
-    run_hooked_actions('POST_RSYNC_ACTIONS')
+    run_hooked_actions('POST_SEND_ACTIONS')
 
     # Update this app in server
-    print section_title('Update app in server')
-    run('bsjack server.update_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
+    print section_title('Install %s in remote' % project_name)
+    run('bsjack server.install_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
 
     # Call post-install script
     run_hooked_actions('POST_INSTALL_ACTIONS')
 
     # Commit state to git repo
-    print section_title('Commit current code to git repo')
+    print section_title('Commit %s in remote' % project_name)
     run('bsjack server.commit_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
     run('bsjack server.reload_app:%s,VERBOSE=%d --hide=status' % (project_name, beanstalk_settings['VERBOSE']))
+
+    print ' . ' * 26
