@@ -96,4 +96,6 @@ def run_hooked_actions(action_name):
                 kwargs = {}
             with hide('status'):
                 execute(action, *args, **kwargs)
-
+        return True
+    else:
+        return False
